@@ -25,9 +25,7 @@ def sqs_delete_message(receipt_handle):
 
     # delete the message that has been processed
     try:
-        c.delete_message(
-            QueueUrl=os.environ["SQS_QUEUE_URL"], ReceiptHandle=receipt_handle
-        )
+        c.delete_message(QueueUrl=os.environ["SQS_QUEUE_URL"], ReceiptHandle=receipt_handle)
     except botocore.exceptions.ClientError as e:
         if e.response["Error"]["Code"] == "AWS.SimpleQueueService.NonExistentQueue":
             logger.error(f"The queue {os.environ['SQS_QUEUE_URL']} does not exist")
@@ -81,9 +79,7 @@ def secrets_manager_get_secret(secret):
         elif e.response["Error"]["Code"] == "InvalidParameterException":
             logger.error(f"The request had invalid params: {e}")
         elif e.response["Error"]["Code"] == "DecryptionFailure":
-            logger.error(
-                f"The requested secret can't be decrypted using the provided KMS key: {e}"
-            )
+            logger.error(f"The requested secret can't be decrypted using the provided KMS key: {e}")
         elif e.response["Error"]["Code"] == "InternalServiceError":
             logger.error(f"An error occurred on service side: {e}")
         else:
@@ -109,7 +105,8 @@ def s3_download(bucket, key):
     c = s.resource("s3")
     logger.info("boto3 s3 client created")
 
-    local_path = tempfile.TemporaryFile()
+    temp_file = tempfile.NamedTemporaryFile()
+    local_path = temp_file.name
 
     try:
         c.Bucket(bucket).download_file(key, local_path)
@@ -121,7 +118,8 @@ def s3_download(bucket, key):
     else:
         logger.info(f"{key} downloaded to {local_path}")
         return local_path
-
+    finally:
+        temp_file.close()
     return None
 
 
